```
Usage: vcd network external list-vsphere-network [OPTIONS] <name>

Options:
  --filter <name==portgroup*>  filter for vSphere Network
  -h, --help                   Show this message and exit.

```
